# Indy-Credx

[![pypi releases](https://img.shields.io/pypi/v/indy_credx)](https://pypi.org/project/indy-credx/)

A Python wrapper around the `indy-credx` Rust library, this module provides support for Hyperledger Indy "Anoncreds" verifiable credential issuance, presentation, and verification.

## Credit

The initial implementation of `indy-shared-rs` was developed by the Verifiable Organizations Network (VON) team based at the Province of British Columbia, and derives largely from the implementations within [Hyperledger Indy-SDK](https://github.com/hyperledger/indy-sdk). To learn more about VON and what's happening with decentralized identity in British Columbia, please go to [https://vonx.io](https://vonx.io).

## Contributing

Pull requests are welcome! Please read our [contributions guide](https://github.com/bcgov/indy-shared-rs/blob/master/CONTRIBUTING.md) and submit your PRs. We enforce [developer certificate of origin](https://developercertificate.org/) (DCO) commit signing. See guidance [here](https://github.com/apps/dco).

We also welcome issues submitted about problems you encounter in using `indy-shared-rs`.

## License

[Apache License Version 2.0](https://github.com/bcgov/indy-shared-rs/blob/master/LICENSE)
